#include <check.h>
#include <errno.h>
#include <stdio.h>
#include <unistd.h>

#include "ttail_check.h"
#include "ttail.h"
#include "ttail_init.h"

START_TEST (test_argparse_reprefix_short)
{
	ttail_t *t;
	char *args[] = {"foo", "-r", "^[^ ]+ "};
	t = ttail_init(3, args);
	ck_assert(t != NULL);
	ck_assert((t->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
}
END_TEST

START_TEST (test_argparse_reprefix_long)
{
	ttail_t *t;
	char *args[] = {"foo", "--re-prefix", "^[^ ]+ "};
	t = ttail_init(3, args);
	ck_assert(t != NULL);
	ck_assert((t->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
}
END_TEST

START_TEST (test_argparse_prefixlen_short)
{
	ttail_t *t;
	char *args[] = {"foo", "-p", "10"};
	t = ttail_init(3, args);
	ck_assert(t != NULL);
	ck_assert((t->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
	ck_assert_int_eq(t->prefix_sz, 10);
}
END_TEST

START_TEST (test_argparse_prefixlen_long)
{
	ttail_t *t;
	char *args[] = {"foo", "--prefix-len", "42"};
	t = ttail_init(3, args);
	ck_assert(t != NULL);
	ck_assert((t->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
	ck_assert_int_eq(t->prefix_sz, 42);
}
END_TEST


START_TEST (test_argparse_prefix_multiple)
{
	ttail_t *t;
	char *args[] = {"foo", "--re-prefix", "^[^ ]+ ", "-p", "20"};
	t = ttail_init(5, args);
	ck_assert(t == NULL);
}
END_TEST

Suite * ttail_init_suite(void)
{
	Suite *s;
	TCase *tc_argparse_prefix;

	s = suite_create("ttail argument parsing checks");

	tc_argparse_prefix = tcase_create("re-prefix arguments parsing");
	tcase_add_test(tc_argparse_prefix, test_argparse_reprefix_short);
	tcase_add_test(tc_argparse_prefix, test_argparse_reprefix_long);
	tcase_add_test(tc_argparse_prefix, test_argparse_prefixlen_short);
	tcase_add_test(tc_argparse_prefix, test_argparse_prefixlen_long);
	tcase_add_test(tc_argparse_prefix, test_argparse_prefix_multiple);

	suite_add_tcase(s, tc_argparse_prefix);
	return s;
}

TTAIL_CHECK_MAIN(ttail_init_suite)
